@@ -206,6 +206,34 @@ class APINexus:
 
         return dataReceived
 
+    def get_rt_data_tagview(self, uid_tagview: str = None, filters=None):
+        """
+        Gets the real time data from Nexus.
+        Args:
+            NX: Nexus object
+            uid_tagview: uid of the tagview. If None, it will select the first one from the token
+            filters: name of the variables to filter. If None, it will select all the variables
+        Returns:
+            df: dataframe with the data
+        """
+        if uid_tagview is None:
+            tagviews = self.callGetDocuments()
+            tagviews = json_normalize(tagviews)
+            uid_tagview = tagviews.uid[0]
+        vbles = pd.DataFrame(self.callGetTagViews(uid_tagview))['columns']
+        vbles = json_normalize(vbles)
+        if filters is None:
+            uids = vbles['uid'].to_list()
+        else:
+            filters = [filters] if isinstance(filters, str) else filters
+            uids = vbles[vbles.name.isin(filters)].uid.to_list()
+        # Read RT values from tagview
+        data = json_normalize(self.callGetTagViewsRealTime(uid_tagview, uids))
+        diccio = dict([(i, j) for i, j in zip(vbles.uid, vbles.name)])
+        data['timeStamp'] = pd.to_datetime(data['timeStamp'], unit='s')
+        data['name'] = data['uid'].map(diccio)
+        return data
+
     def callPostValueRT(self, variable_name, variable_value):
         """Escritura de variable en tiempo real.
         args:
